import chimera, numpy
from chimera import runCommand
from numpy import array, random as rn
from StructBio.Graphs.graph import Graph, Node

runCommand("set bg_color white")

maxX = 64.; maxY = 32.; maxZ = 16.
numNodes = 24

g = Graph("Delaunay Tessellation")

c = array((0.0, 0.0, 0.0))
g.addNode("V001", Node(0.0, c, 2.0, tuple((0.0, 1.0, 0.0))))
c = array((maxX, maxY, maxZ))
g.addNode("V" + "%03d"%numNodes, Node(0.0, c, 2.0, tuple((1.0, 0.0, 0.0))))

for ix in range(2, numNodes):
    c = array((rn.random()*maxX, rn.random()*maxY, rn.random()*maxZ))
    g.addNode("V" + "%03d"%ix,
              Node(0.0, c, 0.7, tuple((rn.random(), rn.random(), rn.random()))))

g.buildDelaunayTessellation(24.0)
g.solids.display()

shortestPath = g.getShortestPathSubgraph("V001", "V" + "%03d"%numNodes, "Shortest Path")
shortestPath.solids.display()

for nodeLabel in shortestPath.orderedPathLabels_L:
    c = shortestPath.vertices_D[nodeLabel].coords
    print "%4s  [%6.2f,%6.2f,%6.2f]" % (nodeLabel, c[0], c[1], c[2])

